==> haskell-implicit-hie-cradle-0.5.0.1-162-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie-cradle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie-cradle
version:              0.5.0.1
visibility:           public
id:                   implicit-hie-cradle-0.5.0.1-ibI6qQdaMm9m0zdRLtwlO
key:                  implicit-hie-cradle-0.5.0.1-ibI6qQdaMm9m0zdRLtwlO
license:              BSD-3-Clause
copyright:            2023
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie-cradle#readme
synopsis:             Auto generate hie-bios cradles
description:          Auto generate a stack or cabal multi component cradles
category:             Development, Tools, Hie, HLS
abi:                  7adab67f0e3259d84ae94990a855e1a7
exposed:              True
exposed-modules:      Hie.Implicit.Cradle
hidden-modules:       Paths_implicit_hie_cradle
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie-cradle
hs-libraries:         HSimplicit-hie-cradle-0.5.0.1-ibI6qQdaMm9m0zdRLtwlO
depends:
    base-4.17.2.1 directory-1.3.7.1 extra-1.7.16-Bd5z33Uz6vY4Zv52jbXbiv
    filepath-1.4.2.2 hie-bios-0.12.0-JZWmmdEARfEbETWYXScbN
    implicit-hie-0.1.4.0-LpN8T9pfgGMAQovpZGq8ak process-1.6.18.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie-cradle/html/implicit-hie-cradle.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie-cradle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-implicit-hie-cradle-0.5.0.1-163-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie-cradle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie-cradle
version:              0.5.0.1
visibility:           public
id:                   implicit-hie-cradle-0.5.0.1-BjBxe2MOCzw93gAviy5084
key:                  implicit-hie-cradle-0.5.0.1-BjBxe2MOCzw93gAviy5084
license:              BSD-3-Clause
copyright:            2023
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie-cradle#readme
synopsis:             Auto generate hie-bios cradles
description:          Auto generate a stack or cabal multi component cradles
category:             Development, Tools, Hie, HLS
abi:                  3f621ecef248b9293207aa2224c60393
exposed:              True
exposed-modules:      Hie.Implicit.Cradle
hidden-modules:       Paths_implicit_hie_cradle
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie-cradle
hs-libraries:         HSimplicit-hie-cradle-0.5.0.1-BjBxe2MOCzw93gAviy5084
depends:
    base-4.17.2.1 directory-1.3.7.1 extra-1.7.16-KGJm7HE8TMo8c4jTE4Z3yy
    filepath-1.4.2.2 hie-bios-0.12.0-5HoGC605uqT5ee0XJckid0
    implicit-hie-0.1.4.0-9uT0V6yNKgWI6GM6VBaCt8 process-1.6.18.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie-cradle/html/implicit-hie-cradle.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie-cradle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
